#
# spec file for package autoconf-archive
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           autoconf-archive
Version:        2023.02.20
Release:        1.6
Summary:        A Collection of macros for GNU autoconf
License:        GPL-3.0-or-later WITH Autoconf-exception-3.0
URL:            https://savannah.gnu.org/projects/autoconf-archive
Source0:        https://ftp.gnu.org/pub/gnu/autoconf-archive/%{name}-%{version}.tar.xz
Source1:        https://ftp.gnu.org/pub/gnu/autoconf-archive/%{name}-%{version}.tar.xz.sig
# http://wwwkeys.pgp.net:11371/pks/lookup?op=get&search=0x99089D72
Source2:        %{name}.keyring
BuildArch:      noarch

%description
The GNU Autoconf Archive is a collection of more than 450 macros for `GNU
Autoconf <http://www.gnu.org/software/autoconf>`_ that have been contributed as
free software by friendly supporters of the cause from all over the Internet.
Every single one of those macros can be re-used without imposing any
restrictions whatsoever on the licensing of the generated `configure` script. In
particular, it is possible to use all those macros in `configure` scripts that
are meant for non-free software. This policy is unusual for a Free Software
Foundation project. The FSF firmly believes that software ought to be free, and
software licenses like the GPL are specifically designed to ensure that
derivative work based on free software must be free as well. In case of
Autoconf, however, an exception has been made, because Autoconf is at such a
pivotal position in the software development tool chain that the benefits from
having this tool available as widely as possible outweigh the disadvantage that
some authors may choose to use it, too, for proprietary software.

%prep
%setup -q

%build
%configure \
	--docdir=%{_docdir}/%{name}
%make_build

%install
%make_install
rm -rf %{buildroot}/%{_datadir}/%{name}/
# install via macro later
rm -v %{buildroot}%{_docdir}/%{name}/COPYING*

%files
%license COPYING*
%doc AUTHORS README
%{_infodir}/%{name}.info*%{ext_info}
%dir %{_datadir}/aclocal
%{_datadir}/aclocal/*.m4

%changelog
* Tue Feb 21 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2023.02.20:
  * This release contains fixes for multiple macros. In preparation
    for Clang 16 it contains multiple compatibility changes.
* Mon Sep  5 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2022.09.03:
  * AX_PYTHON_DEVEL: Improved Python version support
  * ax_boost_json: implement for Boost::JSON library
  * AX_LIB_MYSQL: try pkg-config before mysql_config
  * AX_LUA_HEADERS: update to use AC_COMPUTE_INT
  * ax_lib_netcdf4: enable NF_CONFIG run-time definition.
  * Make assembler-finding macros more portable
  * ax_prog_cc_for_build: Properly restore ac_cv_c_compiler_gnu
* Fri Feb 11 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2022.02.11:
  * AX_CC_FOR_BUILD was deprecated in favor of AX_PROG_CC_FOR_BUILD
* Sun Feb 21 2021 Dirk Müller <dmueller@suse.com>
- update to 2021.02.19:
  * The macros AX_CHECK_PCRE2 and AX_PROG_ROBOT have been added. Many other
    macros have received updates.
* Wed Feb 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Drop info Requires(pre|post) and usage of install_info and
  install_info_delete in the pre/post scriptlets: info files are
  handled by file triggers.
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Mon Jan 14 2019 astieger@suse.com
- update to 2019.01.06:
  * The macro AX_CODE_COVERAGE was modified to use
    AX_ADD_AM_MACRO_STATIC
  * various updates to multiple macros
* Sat Mar 17 2018 astieger@suse.com
- update to 2018.03.13:
  * Add macros packages AX_R_PACKAGE and AX_PROG_DATE
  * updates for other macros
- Use %%license (boo#1082318)
* Thu Oct 12 2017 astieger@suse.com
- update to 2017.09.28:
  * New macros AX_PROG_HELP2MAN, AX_RECURSIVE_EVAL,
    AX_SUBDIRS_CONFIGURE, AX_ELISP, and AX_PROG_EMACS
  * updates to various macros
* Thu Mar 23 2017 mpluskal@suse.com
- Update to version 2017.03.21:
  * Removed macros:
    + AX_CXX_COMPILER_VENDOR
    + AX_GCC_LIBRARIES_DIR
    + AX_GCC_VERSION,
    + AX_HAVE_OPENGL
  * Obsolete macros:
    + AX_DEFINE_SUB_PATH
* Tue Sep 27 2016 astieger@suse.com
- update to 2016.09.16:
  * Added macros:
    + AX_BUILD_DATE_EPOCH
    + AX_CHECK_X86_FEATURES,
    + AX_GCC_X86_CPU_SUPPORTS
    + AX_OPEN62541_CHECK_H
    + AX_OPEN62541_CHECK_LIB
    + AX_LUAROCKS_ROCK.
  * While updating AX_CODE_COVERAGE, the variable
    CODE_COVERAGE_LDFLAGS was renamed to CODE_COVERAGE_LIBS
  * AX_VALGRIND_CHECK has been extended considerably
  * The undocumented internal rule check-valgrind-tool was removed.
  * AX_WITH_CURSES and AX_WITH_CURSES_* macros have been modernized
* Wed Mar 30 2016 fcrozat@suse.com
- Change license tag to "GPL-3.0+ WITH Autoconf-exception-3.0" and
  ship COPYING.EXCEPTION as %%doc.
* Tue Mar 22 2016 mpluskal@suse.com
- Update to 2016.03.20
  * The following new macros have been added: AX_CHECK_GIRS_GJS,
    AX_CHECK_GIR_SYMBOLS_GJS, AX_CXX_COMPILE_STDCXX,
    AX_CXX_COMPILE_STDCXX_14,
    AX_CZMQ, AX_FC_CHECK_DEFINE, AX_LIB_NETCDF4, AX_PROG_GJS,
    AX_RESTORE_FLAGS_WITH_PREFIX, AX_SAVE_FLAGS_WITH_PREFIX,
    AX_VAR_POP, AX_VAR_PUSH, and AX_ZMQ.
  * Various improvements to the opengl macros. Main features added:
    + Support action-if-found and not-found hook
    + Export HAVE_GL, HAVE_GLU, and HAVE_GLUT preprocessor symbol
    + Add necessary flags to CFLAGS/LIBS by default, but can be
    disabled by overwritting action-if-found hook.
    + Fail the configure script if lib not found. This feature can
    be disabled by overwritting action-if-not-found hook
    + Fix problems on Mac OSX. Been tested on Linux (Ubuntu) and
    OSX 6 Use --with-xquartz-gl instead of --with-gl=x for using
    X11 on OSX
  * Many new features were added to AX_CODE_COVERAGE and
    AX_PROG_DOXYGEN.
  * AX_CXX_COMPILE_STDCXX now modifies $(CXX) rather than
    $(CXXFLAGS).
  * AX_PTHREAD has been updated significantly. See
    https://savannah.gnu.org/patch/?8186 for further details.
  * AX_PYTHON_DEVEL now provides PYTHON_LIBS instead of
    PYTHON_FLAGS.
  * The macros related to C++11 and C++14 were extensively
    re-factored.
* Sun Sep 27 2015 mpluskal@suse.com
- Update to 2015.09.25
  * AX_CXX_COMPILE_STDCXX_11 now supports Cray's crayCC compiler
    (CCE 8.4).
  * AX_PYTHON, AX_PYTHON_EMBED now support Python 3.4.
  * AX_LIB_ORACLE_OCI now supports Oracle 12.
  * AX_EXT now supports AVX2/AVX512 and other CPU extensions.
  * The new macro AX_GNU_AUTOTEST was added. The macro supports
    multiple test-suites, Makefiles in different locations and
    many more features.
  * AX_CXX_COMPILE_STDCXX_11 now checks for attribute support with
    C++11 macro.
  * Some compilers pass the other tests while not implementing
    this part of the C++11 specification. The test used also does
    not cause warnings with GCC or Clang, and can be used with
  - Werror.
  * The new macro AX_PROG_BISON_VERSION can be used to check for
    specific versions of bison.
  * The new macro AX_PROG_FLEX_VERSION can be used to check for
    specific versions of flex.
  * AX_APPEND_FLAG no longer fails if the given flag contains a
    ','.
  * AX_LUA now supports Lua 5.3.
  * AX_BERKELEY_DB_CXX now supports FreeBSD.
  * AX_CXX_COMPILE_STDCXX_11 now support HP aCC.
  * AX_PYTHON_MODULE and AX_PYTHON_MODULE_VERSION now support
    Python 3.
  * The new macro AX_PYTHON_MODULE_VERSION has been added.
  * AX_LIB_POSTGRESQL provides a new output variable
    POSTGRESQL_LIBS.
  * AX_PATH_GENERIC now supports flags that contain spaces.
  * AX_BOOST_BASE now supports native Windows header only
    libraries.
- Cleanup spec file with spec-clener
* Sun May 17 2015 meissner@suse.com
- delete info files in the preun section
* Tue Mar  3 2015 astieger@suse.com
- Update to version 2015.02.24:
  * AX_CHECK_ENABLE_DEBUG now uses $ax_is_release as default for
    IS-RELEASE.
  * AX_IS_RELEASE now supports micro-version policies.
  * Portability of AX_CXX_COMPILE_STDCXX_0X has been improved.
  * AX_PROG_HAXE_VERSION is a new macro to detect the presence of
    Haxe
  * AX_COMPILER_FLAGS has undergone extensive re-factoring.
  * AX_COMPILER_FLAGS_CXXFLAGS is a new macro that tests available
    C++ compiler warnings.
  * AX_CXX_COMPILE_STDCXX_11 can now test for SFINAE with template
    aliases.
  * AX_APPEND_FLAG: Fix a regression introduced in the previous
    release.
- includes changes from 2015.02.04
  * AX_OPENMP: Test that we can actually #include <omp.h>
    successfully.
  * AX_COMPILER_FLAGS was re-factored into
    AX_COMPILER_FLAGS_CFLAGS and AX_COMPILER_FLAGS_LDFLAGS.
  * AX_CODE_COVERAGE detects gcov program.
  * AX_VALGRIND_CHECK now supports running without libtool.
  * AX_GCC_VERSION was improved.
  * Re-factored and modernized the macros AX_CXX_TEMPLATES,
    AX_CXX_CONST_CAST, AX_CXX_COMPLEX_MATH_IN_NAMESPACE_STD,
    AX_CXX_BOOL, AX_APPEND_FLAG, AX_CHECK_*_FLAG,
    AX_CHECK_ENABLE_DEBUG, and AX_CXX_DEFAULT_TEMPLATE_PARAMETERS.
  * AX_CXX_COMPILER_VENDOR was deprecated in favor of
    AX_COMPILER_VENDOR.
  * AX_HAVE_OPENGL was deprecated in favor of AX_CHECK_GL,
    AX_CHECK_GLU, AX_CHECK_GLUT, and AX_CHECK_GLX.
  * AX_CHECK_GL has a new parameter --with-mesa that allows
    choosing the order of opengl lib detection.
  * Portability of AX_LUA was improved. Support for LUA 5.0 was
    added.
  * New macros AX_IS_RELEASE, AX_COMPILER_FLAGS_GIR,
    AX_CXX_ERASE_ITERATOR_TYPE, AX_COMPILER_VERSION, AX_CHECK_GLX,
    AX_CHECK_VSCRIPT, AX_VALGRIND_CHECK, AX_PKG_CHECK_MODULES,
    and AX_COMPILER_FLAGS were added.
  * AX_PROG_FLEX: Also accept gflex.
  * AX_LIB_HDF5: remove extra leading space from include path flag.
  * AX_PERL_MODULE_VERSION: use more portable syntax for shell
    arithmetic.
  * AX_PROG_JAVAH_BIN_DIR: fix misspelled variable name and follow
    javah symlinkto find jni.h.
  * AX_BOOST_PYTHON: use unique names for local variables
* Wed Oct 15 2014 andreas.stieger@gmx.de
- Update to version 2014.10.15:
  Many bug fixes and improvements to many macros as well as new
  macros and features. See NEWS for details:
  https://github.com/peti/autoconf-archive/blob/v2014.10.15/NEWS
- includes changes from 2014.02.28, 2013.11.01
- drop autoconf-archive-fix_AX_HAVE_QT.patch, obsolete
- verify source tarball sigature
* Sun Jul 28 2013 p.drouand@gmail.com
- Update to version 2013.06.09
  + AX_PROG_FLEX has been updated to be more liberal about the name of the flex
    executable.
  + AX_LIB_HDF5 has been updated to support the variables HDF5_CC, HDF5_FC, and
    HDF5_LIBS. See <http://savannah.gnu.org/patch/?8026> for further details.
  + AX_XSDCXX has been added; a macro to find the CodeSynthesis XSD executable
    and the corresponding headers. See <http://savannah.gnu.org/patch/?8011>
    for further details.
  + AX_PYTHON_DEVEL no longer overrides LOCALMODLIBS. Further details are
    available at <http://savannah.gnu.org/patch/index.php?8065>.
  + The portability of AX_ZONEINFO has been improved. Further details can be
  found at <http://savannah.gnu.org/patch/index.php?8029>.
  + The configure flags generated by AX_ENABLE_DEFAULT_ACLOCALDIR have been
  fixed.
  + AX_CHECK_GLU and AX_CHECK_GLUT have been added again by a new maintainer.
* Fri Dec  7 2012 p.drouand@gmail.com
- Update to 2012.11.14 version:
  * The portability of AX_BOOST_SYSTEM and AX_BOOST_THREAD has been improved. See
    <http://lists.gnu.org/archive/html/autoconf-archive-maintainers/
    2012-09/msg00026.html> for further details.
  * AX_COUNT_CPUS has been cleaned up. See <http://savannah.gnu.org/patch/?7860>
    for further details.
  * AX_BLAS has been extended to detect the Intel Math Kernel Library (MKL). See
    <http://savannah.gnu.org/patch/?7807> for further details.
  * Several bugs and inconsistencies in AX_TRY_RUN_JAVA, AX_PROG_JAVA_WORKS,
    AX_CHECK_CLASS, and AX_PROG_JAVA have been fixed. See
    <http://savannah.gnu.org/patch/?7835> for further details.
  * AX_INCLUDE_STRCASECMP has been added. The macro detects which header file
    defines the strcasecmp() function. See <http://savannah.gnu.org/patch/?7836>
    for further details.
  * AX_LIB_ORACLE_OCCI has been added. The macro detects the availability of the
    Oracle OCCI API of particular version or newer. Further details can be found
    at <http://savannah.gnu.org/patch/?7834>.
  * AX_CHECK_POSTGRES_DB has been substantially re-written. The default behavior
    is unchanged, but there are two new (optional) arguments ACTION-IF-FOUND and
    ACTION-IF-NOT-FOUND. See <http://savannah.gnu.org/patch/?7832> for further
    details.
  * AX_CXX_RVALUE_REFERENCES has been added. See
    <http://savannah.gnu.org/patch/?7833> for further details.
  * AX_BLAS has been extended to support for the (free-software, BSD-licensed)
    OpenBLAS library, a descendant of GotoBLAS. See
    <http://savannah.gnu.org/patch/?7828> for further details.
  * The reliability of AX_BOOST_SYSTEM and AX_BOOST_FILESYSTEM has been improved.
    See <http://savannah.gnu.org/patch/?7816> for further details.
  * The new entry AX_ZONEINFO has been added. Further details are available at
    <http://savannah.gnu.org/patch/index.php?7814>.
  * AX_CHECK_ZLIB has been updated significantly:
  - The behavior was changed so that the macro proceeds to compile and link
    tests even if zlib.h was not found in the "usual locations".
  - The macro interface has been extend to the typical ([action-if-found],
    [action-if-not-found])-style.
  - Previous versions used to search zlib in "usual locations" only if
  - -with-zlib was provided [by user]. Now, the macro performs that search in
    default mode, too.
- Removed patches: bugs fixed on upstream release:
  * autoconf-archive-ax_have_qt_fix_library_order.patch
  * autoconf-archive-AX_HAVE_QT_use_AS_HELP_STRING.patch
  * autoconf-archive-boost_lib64.patch
  * autoconf-archive-no_semicolon.patch
* Fri Jan 20 2012 cfarrell@suse.com
- license update: SUSE-GPL-3.0+-with-autoconf-exception
  Use SUSE- proprietary extension until license accepted upstream.
  autoconf-archive is not pure GPL-3.0+ as exceptions are involved
* Tue Jan 17 2012 aj@suse.de
- Own /usr/share/aclocal
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Fri Mar 25 2011 pth@suse.de
- Libraries come last, not first in call to linker. Otherwise
  linking fails when as-needed is in effect.
* Wed Mar 23 2011 pth@suse.de
- Newer autoconfs produce wrong code if code snippets consist
  only of coments, so fix ax_have_qt.m4 accordingly.
- Use AS_HELP_STRING in ax_have_qt.m4.
- Remove spurious semicolon from AC_MSG_RESULT call.
* Thu Nov 25 2010 pth@suse.de
- Move the lib64 patch from boost here. This sets lib64 also for
  ppc64 and s390x.
* Wed Nov 24 2010 sbrabec@suse.cz
- Updated to the latest release 2010.10.26.
* Tue Jun  8 2010 pth@suse.de
- Initial openSUSE package.
